summaryrefslogtreecommitdiff
path: root/xmloff/inc/txtlists.hxx
diff options
context:
space:
mode:
authorAlexander O. Anisimov <alenyashka@gmail.com>2010-11-09 01:42:14 +0500
committerCaolán McNamara <caolanm@redhat.com>2010-11-09 11:50:47 +0000
commitdec234ba07197fcfde9bf4e240549ffaa3ba00b4 (patch)
tree590b035fe0575a06214b2a520887074963332a1e /xmloff/inc/txtlists.hxx
parent9569c88f3ba13115e6af4fca17805ef2fc8716e3 (diff)
Clean up the code
* Remove bogus comments * Refresh comments containing a reference to the bug tracker * Remove the comments such as "// add by zhaojianwei"
Diffstat (limited to 'xmloff/inc/txtlists.hxx')
-rw-r--r--xmloff/inc/txtlists.hxx18
1 files changed, 6 insertions, 12 deletions
diff --git a/xmloff/inc/txtlists.hxx b/xmloff/inc/txtlists.hxx
index 67305ad76272..b8735e8b7856 100644
--- a/xmloff/inc/txtlists.hxx
+++ b/xmloff/inc/txtlists.hxx
@@ -66,13 +66,11 @@ class XMLTextListsHelper : private boost::noncopyable
// keeping track of processed lists for import and export
// --> OD 2008-08-15 #i92811#
// - add optional parameter <sListStyleDefaultListId>
void KeepListAsProcessed( ::rtl::OUString sListId,
::rtl::OUString sListStyleName,
::rtl::OUString sContinueListId,
::rtl::OUString sListStyleDefaultListId = ::rtl::OUString() );
- // <--
sal_Bool IsListProcessed( const ::rtl::OUString sListId ) const;
::rtl::OUString GetListStyleOfProcessedList(
@@ -84,11 +82,8 @@ class XMLTextListsHelper : private boost::noncopyable
::rtl::OUString GenerateNewListId() const;
// --> OD 2008-08-15 #i92811#
// provide list id for a certain list block for import
::rtl::OUString GetListIdForListBlock( XMLTextListBlockContext& rListBlock );
- // <--
-
// keep track of continue list chain for export
void StoreLastContinuingList( ::rtl::OUString sListId,
@@ -158,12 +153,11 @@ class XMLTextListsHelper : private boost::noncopyable
::rtl::OUString msLastProcessedListId;
::rtl::OUString msListStyleOfLastProcessedList;
- // --> OD 2008-08-15 #i92811#
- // additional container for processed lists.
- // map with <ListStyleName> as key and pair( <ListId, ListStyleDefaultListId> )
- // as value.
+ /* additional container for processed lists.
+ map with <ListStyleName> as key and pair( <ListId, ListStyleDefaultListId> )
+ as value. (#i92811#)
+ */
tMapForLists* mpMapListIdToListStyleDefaultListId;
- // <--
// container type to build up continue list chain:
// map with <ListId> of master list as key and <ListId> of last list
@@ -66,13 +66,11 @@ class XMLTextListsHelper : private boost::noncopyable
// keeping track of processed lists for import and export
- // --> OD 2008-08-15 #i92811#
- // - add optional parameter <sListStyleDefaultListId>
+ // Add optional parameter <sListStyleDefaultListId> (#i92811#)
void KeepListAsProcessed( ::rtl::OUString sListId,
::rtl::OUString sListStyleName,
@@ -84,11 +82,8 @@ class XMLTextListsHelper : private boost::noncopyable
::rtl::OUString GenerateNewListId() const;
- // --> OD 2008-08-15 #i92811#
- // provide list id for a certain list block for import
+ // Provide list id for a certain list block for import (#i92811#)
::rtl::OUString GetListIdForListBlock( XMLTextListBlockContext& rListBlock );